# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ModelVolume(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'base_path': 'str',
        'bucket_name': 'str',
        'created_dt': 'datetime',
        'deleted_dt': 'datetime',
        'edges': 'ModelVolumeEdges',
        'file_count': 'int',
        'id': 'int',
        'immutable_slug': 'str',
        'is_read_only': 'bool',
        'last_sync_time': 'datetime',
        'role_owner_ref': 'int',
        'role_type': 'str',
        'size': 'int',
        'status': 'str',
        'updated_dt': 'datetime',
        'volume_snapshot_volume': 'int',
        'volume_storage': 'int',
        'volume_workspace': 'int'
    }

    attribute_map = {
        'base_path': 'base_path',
        'bucket_name': 'bucket_name',
        'created_dt': 'created_dt',
        'deleted_dt': 'deleted_dt',
        'edges': 'edges',
        'file_count': 'file_count',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'is_read_only': 'is_read_only',
        'last_sync_time': 'last_sync_time',
        'role_owner_ref': 'role_owner_ref',
        'role_type': 'role_type',
        'size': 'size',
        'status': 'status',
        'updated_dt': 'updated_dt',
        'volume_snapshot_volume': 'volume_snapshot_volume',
        'volume_storage': 'volume_storage',
        'volume_workspace': 'volume_workspace'
    }

    def __init__(self, base_path=None, bucket_name=None, created_dt=None, deleted_dt=None, edges=None, file_count=None, id=None, immutable_slug=None, is_read_only=None, last_sync_time=None, role_owner_ref=None, role_type=None, size=None, status=None, updated_dt=None, volume_snapshot_volume=None, volume_storage=None, volume_workspace=None, local_vars_configuration=None):  # noqa: E501
        """ModelVolume - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._base_path = None
        self._bucket_name = None
        self._created_dt = None
        self._deleted_dt = None
        self._edges = None
        self._file_count = None
        self._id = None
        self._immutable_slug = None
        self._is_read_only = None
        self._last_sync_time = None
        self._role_owner_ref = None
        self._role_type = None
        self._size = None
        self._status = None
        self._updated_dt = None
        self._volume_snapshot_volume = None
        self._volume_storage = None
        self._volume_workspace = None
        self.discriminator = None

        if base_path is not None:
            self.base_path = base_path
        if bucket_name is not None:
            self.bucket_name = bucket_name
        self.created_dt = created_dt
        self.deleted_dt = deleted_dt
        if edges is not None:
            self.edges = edges
        if file_count is not None:
            self.file_count = file_count
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if is_read_only is not None:
            self.is_read_only = is_read_only
        self.last_sync_time = last_sync_time
        if role_owner_ref is not None:
            self.role_owner_ref = role_owner_ref
        if role_type is not None:
            self.role_type = role_type
        if size is not None:
            self.size = size
        if status is not None:
            self.status = status
        self.updated_dt = updated_dt
        self.volume_snapshot_volume = volume_snapshot_volume
        if volume_storage is not None:
            self.volume_storage = volume_storage
        if volume_workspace is not None:
            self.volume_workspace = volume_workspace

    @property
    def base_path(self):
        """Gets the base_path of this ModelVolume.  # noqa: E501


        :return: The base_path of this ModelVolume.  # noqa: E501
        :rtype: str
        """
        return self._base_path

    @base_path.setter
    def base_path(self, base_path):
        """Sets the base_path of this ModelVolume.


        :param base_path: The base_path of this ModelVolume.  # noqa: E501
        :type base_path: str
        """

        self._base_path = base_path

    @property
    def bucket_name(self):
        """Gets the bucket_name of this ModelVolume.  # noqa: E501


        :return: The bucket_name of this ModelVolume.  # noqa: E501
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """Sets the bucket_name of this ModelVolume.


        :param bucket_name: The bucket_name of this ModelVolume.  # noqa: E501
        :type bucket_name: str
        """

        self._bucket_name = bucket_name

    @property
    def created_dt(self):
        """Gets the created_dt of this ModelVolume.  # noqa: E501


        :return: The created_dt of this ModelVolume.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ModelVolume.


        :param created_dt: The created_dt of this ModelVolume.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def deleted_dt(self):
        """Gets the deleted_dt of this ModelVolume.  # noqa: E501


        :return: The deleted_dt of this ModelVolume.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted_dt

    @deleted_dt.setter
    def deleted_dt(self, deleted_dt):
        """Sets the deleted_dt of this ModelVolume.


        :param deleted_dt: The deleted_dt of this ModelVolume.  # noqa: E501
        :type deleted_dt: datetime
        """

        self._deleted_dt = deleted_dt

    @property
    def edges(self):
        """Gets the edges of this ModelVolume.  # noqa: E501


        :return: The edges of this ModelVolume.  # noqa: E501
        :rtype: ModelVolumeEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this ModelVolume.


        :param edges: The edges of this ModelVolume.  # noqa: E501
        :type edges: ModelVolumeEdges
        """

        self._edges = edges

    @property
    def file_count(self):
        """Gets the file_count of this ModelVolume.  # noqa: E501


        :return: The file_count of this ModelVolume.  # noqa: E501
        :rtype: int
        """
        return self._file_count

    @file_count.setter
    def file_count(self, file_count):
        """Sets the file_count of this ModelVolume.


        :param file_count: The file_count of this ModelVolume.  # noqa: E501
        :type file_count: int
        """

        self._file_count = file_count

    @property
    def id(self):
        """Gets the id of this ModelVolume.  # noqa: E501


        :return: The id of this ModelVolume.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelVolume.


        :param id: The id of this ModelVolume.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this ModelVolume.  # noqa: E501


        :return: The immutable_slug of this ModelVolume.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this ModelVolume.


        :param immutable_slug: The immutable_slug of this ModelVolume.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def is_read_only(self):
        """Gets the is_read_only of this ModelVolume.  # noqa: E501


        :return: The is_read_only of this ModelVolume.  # noqa: E501
        :rtype: bool
        """
        return self._is_read_only

    @is_read_only.setter
    def is_read_only(self, is_read_only):
        """Sets the is_read_only of this ModelVolume.


        :param is_read_only: The is_read_only of this ModelVolume.  # noqa: E501
        :type is_read_only: bool
        """

        self._is_read_only = is_read_only

    @property
    def last_sync_time(self):
        """Gets the last_sync_time of this ModelVolume.  # noqa: E501


        :return: The last_sync_time of this ModelVolume.  # noqa: E501
        :rtype: datetime
        """
        return self._last_sync_time

    @last_sync_time.setter
    def last_sync_time(self, last_sync_time):
        """Sets the last_sync_time of this ModelVolume.


        :param last_sync_time: The last_sync_time of this ModelVolume.  # noqa: E501
        :type last_sync_time: datetime
        """

        self._last_sync_time = last_sync_time

    @property
    def role_owner_ref(self):
        """Gets the role_owner_ref of this ModelVolume.  # noqa: E501


        :return: The role_owner_ref of this ModelVolume.  # noqa: E501
        :rtype: int
        """
        return self._role_owner_ref

    @role_owner_ref.setter
    def role_owner_ref(self, role_owner_ref):
        """Sets the role_owner_ref of this ModelVolume.


        :param role_owner_ref: The role_owner_ref of this ModelVolume.  # noqa: E501
        :type role_owner_ref: int
        """

        self._role_owner_ref = role_owner_ref

    @property
    def role_type(self):
        """Gets the role_type of this ModelVolume.  # noqa: E501


        :return: The role_type of this ModelVolume.  # noqa: E501
        :rtype: str
        """
        return self._role_type

    @role_type.setter
    def role_type(self, role_type):
        """Sets the role_type of this ModelVolume.


        :param role_type: The role_type of this ModelVolume.  # noqa: E501
        :type role_type: str
        """

        self._role_type = role_type

    @property
    def size(self):
        """Gets the size of this ModelVolume.  # noqa: E501


        :return: The size of this ModelVolume.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ModelVolume.


        :param size: The size of this ModelVolume.  # noqa: E501
        :type size: int
        """

        self._size = size

    @property
    def status(self):
        """Gets the status of this ModelVolume.  # noqa: E501


        :return: The status of this ModelVolume.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ModelVolume.


        :param status: The status of this ModelVolume.  # noqa: E501
        :type status: str
        """

        self._status = status

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ModelVolume.  # noqa: E501


        :return: The updated_dt of this ModelVolume.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ModelVolume.


        :param updated_dt: The updated_dt of this ModelVolume.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def volume_snapshot_volume(self):
        """Gets the volume_snapshot_volume of this ModelVolume.  # noqa: E501


        :return: The volume_snapshot_volume of this ModelVolume.  # noqa: E501
        :rtype: int
        """
        return self._volume_snapshot_volume

    @volume_snapshot_volume.setter
    def volume_snapshot_volume(self, volume_snapshot_volume):
        """Sets the volume_snapshot_volume of this ModelVolume.


        :param volume_snapshot_volume: The volume_snapshot_volume of this ModelVolume.  # noqa: E501
        :type volume_snapshot_volume: int
        """

        self._volume_snapshot_volume = volume_snapshot_volume

    @property
    def volume_storage(self):
        """Gets the volume_storage of this ModelVolume.  # noqa: E501


        :return: The volume_storage of this ModelVolume.  # noqa: E501
        :rtype: int
        """
        return self._volume_storage

    @volume_storage.setter
    def volume_storage(self, volume_storage):
        """Sets the volume_storage of this ModelVolume.


        :param volume_storage: The volume_storage of this ModelVolume.  # noqa: E501
        :type volume_storage: int
        """

        self._volume_storage = volume_storage

    @property
    def volume_workspace(self):
        """Gets the volume_workspace of this ModelVolume.  # noqa: E501


        :return: The volume_workspace of this ModelVolume.  # noqa: E501
        :rtype: int
        """
        return self._volume_workspace

    @volume_workspace.setter
    def volume_workspace(self, volume_workspace):
        """Sets the volume_workspace of this ModelVolume.


        :param volume_workspace: The volume_workspace of this ModelVolume.  # noqa: E501
        :type volume_workspace: int
        """

        self._volume_workspace = volume_workspace

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelVolume):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelVolume):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ModelExperimentConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_dt': 'datetime',
        'edges': 'ModelExperimentConfigEdges',
        'env_vars': 'dict(str, object)',
        'experiment_config_kernel_image': 'int',
        'experiment_config_kernel_resource_spec': 'int',
        'id': 'int',
        'immutable_slug': 'str',
        'kernel_cluster_select_policies': 'dict(str, object)',
        'start_command': 'str',
        'termination_protection': 'bool',
        'updated_dt': 'datetime',
        'volume_mounts': 'dict(str, object)'
    }

    attribute_map = {
        'created_dt': 'created_dt',
        'edges': 'edges',
        'env_vars': 'env_vars',
        'experiment_config_kernel_image': 'experiment_config_kernel_image',
        'experiment_config_kernel_resource_spec': 'experiment_config_kernel_resource_spec',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'kernel_cluster_select_policies': 'kernel_cluster_select_policies',
        'start_command': 'start_command',
        'termination_protection': 'termination_protection',
        'updated_dt': 'updated_dt',
        'volume_mounts': 'volume_mounts'
    }

    def __init__(self, created_dt=None, edges=None, env_vars=None, experiment_config_kernel_image=None, experiment_config_kernel_resource_spec=None, id=None, immutable_slug=None, kernel_cluster_select_policies=None, start_command=None, termination_protection=None, updated_dt=None, volume_mounts=None, local_vars_configuration=None):  # noqa: E501
        """ModelExperimentConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_dt = None
        self._edges = None
        self._env_vars = None
        self._experiment_config_kernel_image = None
        self._experiment_config_kernel_resource_spec = None
        self._id = None
        self._immutable_slug = None
        self._kernel_cluster_select_policies = None
        self._start_command = None
        self._termination_protection = None
        self._updated_dt = None
        self._volume_mounts = None
        self.discriminator = None

        self.created_dt = created_dt
        if edges is not None:
            self.edges = edges
        if env_vars is not None:
            self.env_vars = env_vars
        if experiment_config_kernel_image is not None:
            self.experiment_config_kernel_image = experiment_config_kernel_image
        self.experiment_config_kernel_resource_spec = experiment_config_kernel_resource_spec
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if kernel_cluster_select_policies is not None:
            self.kernel_cluster_select_policies = kernel_cluster_select_policies
        if start_command is not None:
            self.start_command = start_command
        if termination_protection is not None:
            self.termination_protection = termination_protection
        self.updated_dt = updated_dt
        if volume_mounts is not None:
            self.volume_mounts = volume_mounts

    @property
    def created_dt(self):
        """Gets the created_dt of this ModelExperimentConfig.  # noqa: E501


        :return: The created_dt of this ModelExperimentConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ModelExperimentConfig.


        :param created_dt: The created_dt of this ModelExperimentConfig.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def edges(self):
        """Gets the edges of this ModelExperimentConfig.  # noqa: E501


        :return: The edges of this ModelExperimentConfig.  # noqa: E501
        :rtype: ModelExperimentConfigEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this ModelExperimentConfig.


        :param edges: The edges of this ModelExperimentConfig.  # noqa: E501
        :type edges: ModelExperimentConfigEdges
        """

        self._edges = edges

    @property
    def env_vars(self):
        """Gets the env_vars of this ModelExperimentConfig.  # noqa: E501


        :return: The env_vars of this ModelExperimentConfig.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._env_vars

    @env_vars.setter
    def env_vars(self, env_vars):
        """Sets the env_vars of this ModelExperimentConfig.


        :param env_vars: The env_vars of this ModelExperimentConfig.  # noqa: E501
        :type env_vars: dict(str, object)
        """

        self._env_vars = env_vars

    @property
    def experiment_config_kernel_image(self):
        """Gets the experiment_config_kernel_image of this ModelExperimentConfig.  # noqa: E501


        :return: The experiment_config_kernel_image of this ModelExperimentConfig.  # noqa: E501
        :rtype: int
        """
        return self._experiment_config_kernel_image

    @experiment_config_kernel_image.setter
    def experiment_config_kernel_image(self, experiment_config_kernel_image):
        """Sets the experiment_config_kernel_image of this ModelExperimentConfig.


        :param experiment_config_kernel_image: The experiment_config_kernel_image of this ModelExperimentConfig.  # noqa: E501
        :type experiment_config_kernel_image: int
        """

        self._experiment_config_kernel_image = experiment_config_kernel_image

    @property
    def experiment_config_kernel_resource_spec(self):
        """Gets the experiment_config_kernel_resource_spec of this ModelExperimentConfig.  # noqa: E501


        :return: The experiment_config_kernel_resource_spec of this ModelExperimentConfig.  # noqa: E501
        :rtype: int
        """
        return self._experiment_config_kernel_resource_spec

    @experiment_config_kernel_resource_spec.setter
    def experiment_config_kernel_resource_spec(self, experiment_config_kernel_resource_spec):
        """Sets the experiment_config_kernel_resource_spec of this ModelExperimentConfig.


        :param experiment_config_kernel_resource_spec: The experiment_config_kernel_resource_spec of this ModelExperimentConfig.  # noqa: E501
        :type experiment_config_kernel_resource_spec: int
        """

        self._experiment_config_kernel_resource_spec = experiment_config_kernel_resource_spec

    @property
    def id(self):
        """Gets the id of this ModelExperimentConfig.  # noqa: E501


        :return: The id of this ModelExperimentConfig.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelExperimentConfig.


        :param id: The id of this ModelExperimentConfig.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this ModelExperimentConfig.  # noqa: E501


        :return: The immutable_slug of this ModelExperimentConfig.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this ModelExperimentConfig.


        :param immutable_slug: The immutable_slug of this ModelExperimentConfig.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def kernel_cluster_select_policies(self):
        """Gets the kernel_cluster_select_policies of this ModelExperimentConfig.  # noqa: E501


        :return: The kernel_cluster_select_policies of this ModelExperimentConfig.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._kernel_cluster_select_policies

    @kernel_cluster_select_policies.setter
    def kernel_cluster_select_policies(self, kernel_cluster_select_policies):
        """Sets the kernel_cluster_select_policies of this ModelExperimentConfig.


        :param kernel_cluster_select_policies: The kernel_cluster_select_policies of this ModelExperimentConfig.  # noqa: E501
        :type kernel_cluster_select_policies: dict(str, object)
        """

        self._kernel_cluster_select_policies = kernel_cluster_select_policies

    @property
    def start_command(self):
        """Gets the start_command of this ModelExperimentConfig.  # noqa: E501


        :return: The start_command of this ModelExperimentConfig.  # noqa: E501
        :rtype: str
        """
        return self._start_command

    @start_command.setter
    def start_command(self, start_command):
        """Sets the start_command of this ModelExperimentConfig.


        :param start_command: The start_command of this ModelExperimentConfig.  # noqa: E501
        :type start_command: str
        """

        self._start_command = start_command

    @property
    def termination_protection(self):
        """Gets the termination_protection of this ModelExperimentConfig.  # noqa: E501


        :return: The termination_protection of this ModelExperimentConfig.  # noqa: E501
        :rtype: bool
        """
        return self._termination_protection

    @termination_protection.setter
    def termination_protection(self, termination_protection):
        """Sets the termination_protection of this ModelExperimentConfig.


        :param termination_protection: The termination_protection of this ModelExperimentConfig.  # noqa: E501
        :type termination_protection: bool
        """

        self._termination_protection = termination_protection

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ModelExperimentConfig.  # noqa: E501


        :return: The updated_dt of this ModelExperimentConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ModelExperimentConfig.


        :param updated_dt: The updated_dt of this ModelExperimentConfig.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def volume_mounts(self):
        """Gets the volume_mounts of this ModelExperimentConfig.  # noqa: E501


        :return: The volume_mounts of this ModelExperimentConfig.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._volume_mounts

    @volume_mounts.setter
    def volume_mounts(self, volume_mounts):
        """Sets the volume_mounts of this ModelExperimentConfig.


        :param volume_mounts: The volume_mounts of this ModelExperimentConfig.  # noqa: E501
        :type volume_mounts: dict(str, object)
        """

        self._volume_mounts = volume_mounts

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelExperimentConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelExperimentConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseExperiment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_token_id': 'int',
        'config_id': 'int',
        'created_by_id': 'int',
        'created_dt': 'datetime',
        'endpoints': 'ModelServiceEndpoints',
        'exit_code': 'int',
        'experiment_access_token': 'int',
        'experiment_config': 'int',
        'experiment_created_by': 'int',
        'experiment_kernel_cluster': 'int',
        'experiment_kernel_cluster_node': 'int',
        'experiment_project': 'int',
        'experiment_workspace': 'int',
        'final_cost': 'float',
        'id': 'int',
        'immutable_slug': 'str',
        'kernel_cluster_id': 'int',
        'kernel_cluster_node_id': 'int',
        'message': 'str',
        'metrics_summary': 'ModelExperimentMetricsSummary',
        'name': 'str',
        'number': 'int',
        'plot_volume_id': 'int',
        'project_id': 'int',
        'status': 'str',
        'status_last_updated': 'datetime',
        'status_reason': 'str',
        'updated_dt': 'datetime',
        'workspace_id': 'int'
    }

    attribute_map = {
        'access_token_id': 'access_token_id',
        'config_id': 'config_id',
        'created_by_id': 'created_by_id',
        'created_dt': 'created_dt',
        'endpoints': 'endpoints',
        'exit_code': 'exit_code',
        'experiment_access_token': 'experiment_access_token',
        'experiment_config': 'experiment_config',
        'experiment_created_by': 'experiment_created_by',
        'experiment_kernel_cluster': 'experiment_kernel_cluster',
        'experiment_kernel_cluster_node': 'experiment_kernel_cluster_node',
        'experiment_project': 'experiment_project',
        'experiment_workspace': 'experiment_workspace',
        'final_cost': 'final_cost',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'kernel_cluster_id': 'kernel_cluster_id',
        'kernel_cluster_node_id': 'kernel_cluster_node_id',
        'message': 'message',
        'metrics_summary': 'metrics_summary',
        'name': 'name',
        'number': 'number',
        'plot_volume_id': 'plot_volume_id',
        'project_id': 'project_id',
        'status': 'status',
        'status_last_updated': 'status_last_updated',
        'status_reason': 'status_reason',
        'updated_dt': 'updated_dt',
        'workspace_id': 'workspace_id'
    }

    def __init__(self, access_token_id=None, config_id=None, created_by_id=None, created_dt=None, endpoints=None, exit_code=None, experiment_access_token=None, experiment_config=None, experiment_created_by=None, experiment_kernel_cluster=None, experiment_kernel_cluster_node=None, experiment_project=None, experiment_workspace=None, final_cost=None, id=None, immutable_slug=None, kernel_cluster_id=None, kernel_cluster_node_id=None, message=None, metrics_summary=None, name=None, number=None, plot_volume_id=None, project_id=None, status=None, status_last_updated=None, status_reason=None, updated_dt=None, workspace_id=None, local_vars_configuration=None):  # noqa: E501
        """ResponseExperiment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._access_token_id = None
        self._config_id = None
        self._created_by_id = None
        self._created_dt = None
        self._endpoints = None
        self._exit_code = None
        self._experiment_access_token = None
        self._experiment_config = None
        self._experiment_created_by = None
        self._experiment_kernel_cluster = None
        self._experiment_kernel_cluster_node = None
        self._experiment_project = None
        self._experiment_workspace = None
        self._final_cost = None
        self._id = None
        self._immutable_slug = None
        self._kernel_cluster_id = None
        self._kernel_cluster_node_id = None
        self._message = None
        self._metrics_summary = None
        self._name = None
        self._number = None
        self._plot_volume_id = None
        self._project_id = None
        self._status = None
        self._status_last_updated = None
        self._status_reason = None
        self._updated_dt = None
        self._workspace_id = None
        self.discriminator = None

        self.access_token_id = access_token_id
        self.config_id = config_id
        self.created_by_id = created_by_id
        self.created_dt = created_dt
        if endpoints is not None:
            self.endpoints = endpoints
        self.exit_code = exit_code
        self.experiment_access_token = experiment_access_token
        self.experiment_config = experiment_config
        self.experiment_created_by = experiment_created_by
        self.experiment_kernel_cluster = experiment_kernel_cluster
        self.experiment_kernel_cluster_node = experiment_kernel_cluster_node
        self.experiment_project = experiment_project
        self.experiment_workspace = experiment_workspace
        self.final_cost = final_cost
        self.id = id
        self.immutable_slug = immutable_slug
        self.kernel_cluster_id = kernel_cluster_id
        self.kernel_cluster_node_id = kernel_cluster_node_id
        self.message = message
        if metrics_summary is not None:
            self.metrics_summary = metrics_summary
        self.name = name
        self.number = number
        self.plot_volume_id = plot_volume_id
        self.project_id = project_id
        self.status = status
        self.status_last_updated = status_last_updated
        self.status_reason = status_reason
        self.updated_dt = updated_dt
        self.workspace_id = workspace_id

    @property
    def access_token_id(self):
        """Gets the access_token_id of this ResponseExperiment.  # noqa: E501


        :return: The access_token_id of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._access_token_id

    @access_token_id.setter
    def access_token_id(self, access_token_id):
        """Sets the access_token_id of this ResponseExperiment.


        :param access_token_id: The access_token_id of this ResponseExperiment.  # noqa: E501
        :type access_token_id: int
        """

        self._access_token_id = access_token_id

    @property
    def config_id(self):
        """Gets the config_id of this ResponseExperiment.  # noqa: E501


        :return: The config_id of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._config_id

    @config_id.setter
    def config_id(self, config_id):
        """Sets the config_id of this ResponseExperiment.


        :param config_id: The config_id of this ResponseExperiment.  # noqa: E501
        :type config_id: int
        """
        if self.local_vars_configuration.client_side_validation and config_id is None:  # noqa: E501
            raise ValueError("Invalid value for `config_id`, must not be `None`")  # noqa: E501

        self._config_id = config_id

    @property
    def created_by_id(self):
        """Gets the created_by_id of this ResponseExperiment.  # noqa: E501


        :return: The created_by_id of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """Sets the created_by_id of this ResponseExperiment.


        :param created_by_id: The created_by_id of this ResponseExperiment.  # noqa: E501
        :type created_by_id: int
        """
        if self.local_vars_configuration.client_side_validation and created_by_id is None:  # noqa: E501
            raise ValueError("Invalid value for `created_by_id`, must not be `None`")  # noqa: E501

        self._created_by_id = created_by_id

    @property
    def created_dt(self):
        """Gets the created_dt of this ResponseExperiment.  # noqa: E501


        :return: The created_dt of this ResponseExperiment.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ResponseExperiment.


        :param created_dt: The created_dt of this ResponseExperiment.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def endpoints(self):
        """Gets the endpoints of this ResponseExperiment.  # noqa: E501


        :return: The endpoints of this ResponseExperiment.  # noqa: E501
        :rtype: ModelServiceEndpoints
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """Sets the endpoints of this ResponseExperiment.


        :param endpoints: The endpoints of this ResponseExperiment.  # noqa: E501
        :type endpoints: ModelServiceEndpoints
        """

        self._endpoints = endpoints

    @property
    def exit_code(self):
        """Gets the exit_code of this ResponseExperiment.  # noqa: E501


        :return: The exit_code of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._exit_code

    @exit_code.setter
    def exit_code(self, exit_code):
        """Sets the exit_code of this ResponseExperiment.


        :param exit_code: The exit_code of this ResponseExperiment.  # noqa: E501
        :type exit_code: int
        """

        self._exit_code = exit_code

    @property
    def experiment_access_token(self):
        """Gets the experiment_access_token of this ResponseExperiment.  # noqa: E501


        :return: The experiment_access_token of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._experiment_access_token

    @experiment_access_token.setter
    def experiment_access_token(self, experiment_access_token):
        """Sets the experiment_access_token of this ResponseExperiment.


        :param experiment_access_token: The experiment_access_token of this ResponseExperiment.  # noqa: E501
        :type experiment_access_token: int
        """

        self._experiment_access_token = experiment_access_token

    @property
    def experiment_config(self):
        """Gets the experiment_config of this ResponseExperiment.  # noqa: E501


        :return: The experiment_config of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._experiment_config

    @experiment_config.setter
    def experiment_config(self, experiment_config):
        """Sets the experiment_config of this ResponseExperiment.


        :param experiment_config: The experiment_config of this ResponseExperiment.  # noqa: E501
        :type experiment_config: int
        """
        if self.local_vars_configuration.client_side_validation and experiment_config is None:  # noqa: E501
            raise ValueError("Invalid value for `experiment_config`, must not be `None`")  # noqa: E501

        self._experiment_config = experiment_config

    @property
    def experiment_created_by(self):
        """Gets the experiment_created_by of this ResponseExperiment.  # noqa: E501


        :return: The experiment_created_by of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._experiment_created_by

    @experiment_created_by.setter
    def experiment_created_by(self, experiment_created_by):
        """Sets the experiment_created_by of this ResponseExperiment.


        :param experiment_created_by: The experiment_created_by of this ResponseExperiment.  # noqa: E501
        :type experiment_created_by: int
        """
        if self.local_vars_configuration.client_side_validation and experiment_created_by is None:  # noqa: E501
            raise ValueError("Invalid value for `experiment_created_by`, must not be `None`")  # noqa: E501

        self._experiment_created_by = experiment_created_by

    @property
    def experiment_kernel_cluster(self):
        """Gets the experiment_kernel_cluster of this ResponseExperiment.  # noqa: E501


        :return: The experiment_kernel_cluster of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._experiment_kernel_cluster

    @experiment_kernel_cluster.setter
    def experiment_kernel_cluster(self, experiment_kernel_cluster):
        """Sets the experiment_kernel_cluster of this ResponseExperiment.


        :param experiment_kernel_cluster: The experiment_kernel_cluster of this ResponseExperiment.  # noqa: E501
        :type experiment_kernel_cluster: int
        """

        self._experiment_kernel_cluster = experiment_kernel_cluster

    @property
    def experiment_kernel_cluster_node(self):
        """Gets the experiment_kernel_cluster_node of this ResponseExperiment.  # noqa: E501


        :return: The experiment_kernel_cluster_node of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._experiment_kernel_cluster_node

    @experiment_kernel_cluster_node.setter
    def experiment_kernel_cluster_node(self, experiment_kernel_cluster_node):
        """Sets the experiment_kernel_cluster_node of this ResponseExperiment.


        :param experiment_kernel_cluster_node: The experiment_kernel_cluster_node of this ResponseExperiment.  # noqa: E501
        :type experiment_kernel_cluster_node: int
        """

        self._experiment_kernel_cluster_node = experiment_kernel_cluster_node

    @property
    def experiment_project(self):
        """Gets the experiment_project of this ResponseExperiment.  # noqa: E501


        :return: The experiment_project of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._experiment_project

    @experiment_project.setter
    def experiment_project(self, experiment_project):
        """Sets the experiment_project of this ResponseExperiment.


        :param experiment_project: The experiment_project of this ResponseExperiment.  # noqa: E501
        :type experiment_project: int
        """
        if self.local_vars_configuration.client_side_validation and experiment_project is None:  # noqa: E501
            raise ValueError("Invalid value for `experiment_project`, must not be `None`")  # noqa: E501

        self._experiment_project = experiment_project

    @property
    def experiment_workspace(self):
        """Gets the experiment_workspace of this ResponseExperiment.  # noqa: E501


        :return: The experiment_workspace of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._experiment_workspace

    @experiment_workspace.setter
    def experiment_workspace(self, experiment_workspace):
        """Sets the experiment_workspace of this ResponseExperiment.


        :param experiment_workspace: The experiment_workspace of this ResponseExperiment.  # noqa: E501
        :type experiment_workspace: int
        """
        if self.local_vars_configuration.client_side_validation and experiment_workspace is None:  # noqa: E501
            raise ValueError("Invalid value for `experiment_workspace`, must not be `None`")  # noqa: E501

        self._experiment_workspace = experiment_workspace

    @property
    def final_cost(self):
        """Gets the final_cost of this ResponseExperiment.  # noqa: E501


        :return: The final_cost of this ResponseExperiment.  # noqa: E501
        :rtype: float
        """
        return self._final_cost

    @final_cost.setter
    def final_cost(self, final_cost):
        """Sets the final_cost of this ResponseExperiment.


        :param final_cost: The final_cost of this ResponseExperiment.  # noqa: E501
        :type final_cost: float
        """

        self._final_cost = final_cost

    @property
    def id(self):
        """Gets the id of this ResponseExperiment.  # noqa: E501


        :return: The id of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseExperiment.


        :param id: The id of this ResponseExperiment.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this ResponseExperiment.  # noqa: E501


        :return: The immutable_slug of this ResponseExperiment.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this ResponseExperiment.


        :param immutable_slug: The immutable_slug of this ResponseExperiment.  # noqa: E501
        :type immutable_slug: str
        """
        if self.local_vars_configuration.client_side_validation and immutable_slug is None:  # noqa: E501
            raise ValueError("Invalid value for `immutable_slug`, must not be `None`")  # noqa: E501

        self._immutable_slug = immutable_slug

    @property
    def kernel_cluster_id(self):
        """Gets the kernel_cluster_id of this ResponseExperiment.  # noqa: E501


        :return: The kernel_cluster_id of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._kernel_cluster_id

    @kernel_cluster_id.setter
    def kernel_cluster_id(self, kernel_cluster_id):
        """Sets the kernel_cluster_id of this ResponseExperiment.


        :param kernel_cluster_id: The kernel_cluster_id of this ResponseExperiment.  # noqa: E501
        :type kernel_cluster_id: int
        """

        self._kernel_cluster_id = kernel_cluster_id

    @property
    def kernel_cluster_node_id(self):
        """Gets the kernel_cluster_node_id of this ResponseExperiment.  # noqa: E501


        :return: The kernel_cluster_node_id of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._kernel_cluster_node_id

    @kernel_cluster_node_id.setter
    def kernel_cluster_node_id(self, kernel_cluster_node_id):
        """Sets the kernel_cluster_node_id of this ResponseExperiment.


        :param kernel_cluster_node_id: The kernel_cluster_node_id of this ResponseExperiment.  # noqa: E501
        :type kernel_cluster_node_id: int
        """

        self._kernel_cluster_node_id = kernel_cluster_node_id

    @property
    def message(self):
        """Gets the message of this ResponseExperiment.  # noqa: E501


        :return: The message of this ResponseExperiment.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ResponseExperiment.


        :param message: The message of this ResponseExperiment.  # noqa: E501
        :type message: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def metrics_summary(self):
        """Gets the metrics_summary of this ResponseExperiment.  # noqa: E501


        :return: The metrics_summary of this ResponseExperiment.  # noqa: E501
        :rtype: ModelExperimentMetricsSummary
        """
        return self._metrics_summary

    @metrics_summary.setter
    def metrics_summary(self, metrics_summary):
        """Sets the metrics_summary of this ResponseExperiment.


        :param metrics_summary: The metrics_summary of this ResponseExperiment.  # noqa: E501
        :type metrics_summary: ModelExperimentMetricsSummary
        """

        self._metrics_summary = metrics_summary

    @property
    def name(self):
        """Gets the name of this ResponseExperiment.  # noqa: E501


        :return: The name of this ResponseExperiment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResponseExperiment.


        :param name: The name of this ResponseExperiment.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def number(self):
        """Gets the number of this ResponseExperiment.  # noqa: E501


        :return: The number of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this ResponseExperiment.


        :param number: The number of this ResponseExperiment.  # noqa: E501
        :type number: int
        """
        if self.local_vars_configuration.client_side_validation and number is None:  # noqa: E501
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def plot_volume_id(self):
        """Gets the plot_volume_id of this ResponseExperiment.  # noqa: E501


        :return: The plot_volume_id of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._plot_volume_id

    @plot_volume_id.setter
    def plot_volume_id(self, plot_volume_id):
        """Sets the plot_volume_id of this ResponseExperiment.


        :param plot_volume_id: The plot_volume_id of this ResponseExperiment.  # noqa: E501
        :type plot_volume_id: int
        """
        if self.local_vars_configuration.client_side_validation and plot_volume_id is None:  # noqa: E501
            raise ValueError("Invalid value for `plot_volume_id`, must not be `None`")  # noqa: E501

        self._plot_volume_id = plot_volume_id

    @property
    def project_id(self):
        """Gets the project_id of this ResponseExperiment.  # noqa: E501


        :return: The project_id of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ResponseExperiment.


        :param project_id: The project_id of this ResponseExperiment.  # noqa: E501
        :type project_id: int
        """
        if self.local_vars_configuration.client_side_validation and project_id is None:  # noqa: E501
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def status(self):
        """Gets the status of this ResponseExperiment.  # noqa: E501


        :return: The status of this ResponseExperiment.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseExperiment.


        :param status: The status of this ResponseExperiment.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def status_last_updated(self):
        """Gets the status_last_updated of this ResponseExperiment.  # noqa: E501


        :return: The status_last_updated of this ResponseExperiment.  # noqa: E501
        :rtype: datetime
        """
        return self._status_last_updated

    @status_last_updated.setter
    def status_last_updated(self, status_last_updated):
        """Sets the status_last_updated of this ResponseExperiment.


        :param status_last_updated: The status_last_updated of this ResponseExperiment.  # noqa: E501
        :type status_last_updated: datetime
        """
        if self.local_vars_configuration.client_side_validation and status_last_updated is None:  # noqa: E501
            raise ValueError("Invalid value for `status_last_updated`, must not be `None`")  # noqa: E501

        self._status_last_updated = status_last_updated

    @property
    def status_reason(self):
        """Gets the status_reason of this ResponseExperiment.  # noqa: E501


        :return: The status_reason of this ResponseExperiment.  # noqa: E501
        :rtype: str
        """
        return self._status_reason

    @status_reason.setter
    def status_reason(self, status_reason):
        """Sets the status_reason of this ResponseExperiment.


        :param status_reason: The status_reason of this ResponseExperiment.  # noqa: E501
        :type status_reason: str
        """
        if self.local_vars_configuration.client_side_validation and status_reason is None:  # noqa: E501
            raise ValueError("Invalid value for `status_reason`, must not be `None`")  # noqa: E501

        self._status_reason = status_reason

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ResponseExperiment.  # noqa: E501


        :return: The updated_dt of this ResponseExperiment.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ResponseExperiment.


        :param updated_dt: The updated_dt of this ResponseExperiment.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def workspace_id(self):
        """Gets the workspace_id of this ResponseExperiment.  # noqa: E501


        :return: The workspace_id of this ResponseExperiment.  # noqa: E501
        :rtype: int
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this ResponseExperiment.


        :param workspace_id: The workspace_id of this ResponseExperiment.  # noqa: E501
        :type workspace_id: int
        """
        if self.local_vars_configuration.client_side_validation and workspace_id is None:  # noqa: E501
            raise ValueError("Invalid value for `workspace_id`, must not be `None`")  # noqa: E501

        self._workspace_id = workspace_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseExperiment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseExperiment):
            return True

        return self.to_dict() != other.to_dict()



import inquirer
import typer

from savvihub.api.exceptions import NotFoundAPIException
from savvihub.cli.constants import PROJECT_TYPE_CLI_DRIVEN
from savvihub.cli.exceptions import ExitException, InvalidGitRepository
from savvihub.cli.git import GitRepository
from savvihub.cli.typer import Context


def eval_project_type(project, project_type: str) -> bool:
    if project.type != project_type:
        raise ExitException(f'Project `{project.name}` type `{project.type}` does not match with `{project_type}`')
    return True

def project_name_callback(ctx: Context, project_name: str) -> str:
    workspace_name = ctx.params['workspace_name']
    try:
        git_repo = GitRepository()
        owner, repo_name, _ = git_repo._get_github_repo()
        if project_name:
            try:
                ctx.project = ctx.authenticated_client.project_read(workspace_name, project_name)
            except NotFoundAPIException:
                raise ExitException(f'Project `{project_name}` does not exist in the workspace `{workspace_name}`.')

            if ctx.project.cached_git_owner_slug == owner and ctx.project.cached_git_repo_slug == repo_name:
                ctx.git_repo = git_repo
        else:
            projects = ctx.authenticated_client.project_list(workspace_name).results
            matched_projects = []
            for project in projects:
                if project.cached_git_owner_slug == owner and project.cached_git_repo_slug == repo_name:
                    matched_projects.append(project)
            if len(matched_projects) == 1:
                ctx.project = matched_projects[0]
                ctx.git_repo = git_repo
            elif len(matched_projects) > 1:
                ctx.project = inquirer.prompt([inquirer.List(
                    'project',
                    message='Select project',
                    choices=[(p.name, p) for p in matched_projects],
                )]).get('project')
                ctx.git_repo = git_repo
            else:
                ctx.project = inquirer.prompt([inquirer.List(
                    'project',
                    message='Select project',
                    choices=[(p.name, p) for p in projects],
                )]).get('project')

        return ctx.project.name

    except InvalidGitRepository:
        if project_name:
            try:
                project = ctx.authenticated_client.project_read(workspace_name, project_name)
                if eval_project_type(project, PROJECT_TYPE_CLI_DRIVEN):
                    ctx.project = project
            except NotFoundAPIException:
                raise ExitException(f'Project `{project_name}` does not exist in the workspace `{workspace_name}`.')
            return project_name
        else:
            projects = ctx.authenticated_client.project_list(workspace_name).results
            if not projects:
                raise ExitException(f'No project found in workspace `{workspace_name}`')

            if len(projects) == 1:
                project = projects[0]
                if eval_project_type(project, PROJECT_TYPE_CLI_DRIVEN):
                    ctx.project = project
            else:
                project = inquirer.prompt([inquirer.List(
                    'project',
                    message='Select project',
                    choices=[(p.name, p) for p in projects],
                )]).get('project')
                if eval_project_type(project, PROJECT_TYPE_CLI_DRIVEN):
                    ctx.project = project
            return ctx.project.name


project_name_option = typer.Option(None, '--project', callback=project_name_callback,
                                   help='If not present, uses git repository name of the current directory.')



import os

import requests
from tqdm import tqdm
from tqdm.utils import CallbackIOWrapper

from savvihub.common.utils import read_in_chunks


class UploadableFileObject:
    def __init__(self, url, base_path, path):
        self.url = url
        self.base_path = base_path
        self.full_path = os.path.join(base_path, path)
        self.path = path

    def upload_chunks(self, *, callback=None):
        return read_in_chunks(self.full_path, callback=callback)

    def upload_hooks(self, *, callback=None):
        def fn(resp, **kwargs):
            if resp.status_code != 200:
                print(f'Upload for {resp.request.url} failed. Detail: {resp.data}')
        return {
            'response': fn,
        }

    def upload(self, session=requests.Session()):
        file_size = os.path.getsize(self.full_path)

        # send empty data when file is empty
        if os.stat(self.full_path).st_size == 0:
            future = session.put(
                self.url,
                data='',
                headers={'content-type': 'application/octet-stream'},
                hooks=self.upload_hooks(),
            )
            return future

        with open(self.full_path, "rb") as f:
            with tqdm(total=file_size, desc=self.path, unit="B", unit_scale=True, unit_divisor=1024) as t:
                wrapped_file = CallbackIOWrapper(t.update, f, "read")
                requests.put(self.url, data=wrapped_file)
        return


class DownloadableFileObject:
    def __init__(self, url, base_path, path, size=None):
        self.url = url
        self.full_path = os.path.join(base_path, path)
        self.size = size

    def download_hooks(self, *, callback=None):
        def fn(resp, **kwargs):
            os.makedirs(os.path.dirname(self.full_path), exist_ok=True)
            with open(self.full_path, 'wb') as f:
                for chunk in resp.iter_content(chunk_size=8192):
                    f.write(chunk)
                    if callback:
                        callback(chunk)
        return {
            'response': fn,
        }

    def download(self, session=requests.Session(), progressable=None):
        progress_callback = None
        if progressable and self.size:
            progress = progressable(length=self.size, label=self.full_path)
            progress_callback = lambda data: progress.update(len(data))

        future = session.get(
            self.url,
            stream=True,
            hooks=self.download_hooks(callback=progress_callback)
        )
        return future



import os

from savvihub.cli.constants import WEB_HOST, PROJECT_ROOT
from savvihub.common.utils import random_string
from tests.conftest import BaseTestCase


class DatasetTest(BaseTestCase):
    def test_dataset(self):
        # Check current datasets
        result = self.runner.invoke(['dataset', 'list'])
        initial_line_count = len(result.output.split('\n'))

        # Missing argument
        result = self.runner.invoke(['dataset', 'create'], allow_fail=True)
        assert "Error: Missing argument 'DATASET_NAME'" in result.output

        dataset1_name = random_string()
        # Create dataset with invalid dataset formats
        result = self.runner.invoke(['dataset', 'create', f'{self.workspace_name}/{dataset1_name}'], allow_fail=True)
        assert result.exit_code == 1
        assert 'Lower-case alphabets, digits and hyphen can be used.' in result.output

        # Create dataset with valid dataset formats
        result = self.runner.invoke(['dataset', 'create', dataset1_name])
        assert f'Dataset {dataset1_name} is created.' in result.output
        assert f'{WEB_HOST}/{self.workspace_name}/datasets/{dataset1_name}' in result.output
        dataset_name = random_string()
        result = self.runner.invoke(['dataset', 'create', dataset_name])
        assert f'Dataset {dataset_name} is created.' in result.output
        assert f'{WEB_HOST}/{self.workspace_name}/datasets/{dataset_name}' in result.output

        # Two datasets have been created
        result = self.runner.invoke(['dataset', 'list'])
        assert len(result.output.split('\n')) == initial_line_count + 2

        # Empty dataset
        dataset_root = f'svds://{self.workspace_name}/{dataset_name}'
        result = self.runner.invoke(['dataset', 'files', 'ls', dataset_root])
        assert 'This directory is empty' in result.output

        # Upload one file
        test_files_root = os.path.join(PROJECT_ROOT, 'tests/test_files')
        self.runner.invoke(['dataset', 'files', 'cp', f'{test_files_root}/test_dir/b.txt', dataset_root])
        result = self.runner.invoke(['dataset', 'files', 'ls', dataset_root])
        assert 'b.txt' in result.output
        self.runner.invoke(['dataset', 'files', 'cp', '-r', f'{test_files_root}/test_dir/b.txt', f'{dataset_root}/c.txt'])
        result = self.runner.invoke(['dataset', 'files', 'ls', dataset_root])
        assert 'c.txt' in result.output

        # Upload a directory itself
        self.runner.invoke(['dataset', 'files', 'cp', '-r', test_files_root, dataset_root])
        result = self.runner.invoke(['dataset', 'files', 'ls', dataset_root])
        assert 'test_files' in result.output

        # Upload contents of a directory
        self.runner.invoke(['dataset', 'files', 'cp', '-r', f'{test_files_root}/', dataset_root])
        result = self.runner.invoke(['dataset', 'files', 'ls', dataset_root])
        assert 'test_dir' in result.output
        assert 'a.txt' in result.output

        # Copy one file
        self.runner.invoke(['dataset', 'files', 'cp', f'{dataset_root}/a.txt', f'{dataset_root}/copied.txt'])
        result = self.runner.invoke(['dataset', 'files', 'ls', dataset_root])
        assert 'copied.txt' in result.output

        # Copy a directory itself
        self.runner.invoke(['dataset', 'files', 'cp', '-r', f'{dataset_root}/test_dir', f'{dataset_root}/copied_dir'])
        result = self.runner.invoke(['dataset', 'files', 'ls', dataset_root])
        assert 'copied_dir' in result.output

        # Remove one file
        self.runner.invoke(['dataset', 'files', 'rm', f'{dataset_root}/copied_dir/b.txt'])
        result = self.runner.invoke(['dataset', 'files', 'ls', f'{dataset_root}/copied_dir'])
        assert 'b.txt' not in result.output
        assert 'test_dir2' in result.output

        # Copy contents of a directory
        self.runner.invoke(['dataset', 'files', 'cp', '-r', f'{dataset_root}/test_dir/', f'{dataset_root}/copied_dir'])
        result = self.runner.invoke(['dataset', 'files', 'ls', f'{dataset_root}/copied_dir'])
        assert 'b.txt' in result.output
        assert 'test_dir2' in result.output

        # Remove a directory
        self.runner.invoke(['dataset', 'files', 'rm', '-r', f'{dataset_root}/copied_dir'])
        result = self.runner.invoke(['dataset', 'files', 'ls', dataset_root])
        assert 'copied_dir' not in result.output

        # Download a file
        self.runner.invoke(['dataset', 'files', 'cp', f'{dataset_root}/a.txt', f'{test_files_root}'])
        self.runner.invoke(['dataset', 'files', 'cp', f'{dataset_root}/a.txt', f'{test_files_root}/c.txt'])
        os.remove(f'{test_files_root}/c.txt')

        # Download a directory
        self.runner.invoke(['dataset', 'files', 'cp', '-r', f'{dataset_root}/test_files', f'{test_files_root}'])
        assert os.path.exists(f'{test_files_root}/test_files')
        os.system(f'rm -r {test_files_root}/test_files')

        # Download a directory
        self.runner.invoke(['dataset', 'files', 'cp', '-r', f'{dataset_root}/test_dir/test_dir2', f'{test_files_root}'])
        assert os.path.exists(f'{test_files_root}/test_dir2')
        os.system(f'rm -r {test_files_root}/test_dir2')

        # Download contents of a directory
        self.runner.invoke(['dataset', 'files', 'cp', '-r', f'{dataset_root}/test_dir/', f'{test_files_root}'])
        os.remove(f'{test_files_root}/b.txt')
        assert os.path.exists(f'{test_files_root}/test_dir2')
        os.system(f'rm -r {test_files_root}/test_dir2')

        # Remove root
        self.runner.invoke(['dataset', 'files', 'rm', '-r', dataset_root])
        result = self.runner.invoke(['dataset', 'files', 'ls', dataset_root])
        assert 'This directory is empty' in result.output



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseExperimentInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_token_id': 'int',
        'cli_driven_project': 'ResponseCLIDrivenProject',
        'config_id': 'int',
        'created_by': 'ResponseUser',
        'created_by_id': 'int',
        'created_dt': 'datetime',
        'endpoints': 'ResponseServiceEndpoints',
        'env_vars': 'ModelEnvVars',
        'exit_code': 'int',
        'experiment_access_token': 'int',
        'experiment_config': 'int',
        'experiment_config_kernel_image': 'int',
        'experiment_config_kernel_resource_spec': 'int',
        'experiment_created_by': 'int',
        'experiment_kernel_cluster': 'int',
        'experiment_kernel_cluster_node': 'int',
        'experiment_project': 'int',
        'experiment_workspace': 'int',
        'final_cost': 'float',
        'histories': 'list[ResponseExperimentHistoryInfo]',
        'id': 'int',
        'immutable_slug': 'str',
        'kernel_cluster': 'ResponseKernelCluster',
        'kernel_cluster_id': 'int',
        'kernel_cluster_node': 'ResponseKernelClusterNode',
        'kernel_cluster_node_id': 'int',
        'kernel_cluster_select_policies': 'ModelKernelClusterSelectPolicies',
        'kernel_image': 'ResponseKernelImage',
        'kernel_image_id': 'int',
        'kernel_resource_spec': 'ResponseKernelResourceSpec',
        'kernel_resource_spec_id': 'int',
        'message': 'str',
        'metrics_summary': 'ModelExperimentMetricsSummary',
        'name': 'str',
        'number': 'int',
        'plot_volume_id': 'int',
        'project': 'ResponseProject',
        'project_id': 'int',
        'reproduce_command': 'str',
        'slug': 'str',
        'source_code_link': 'list[ResponseProjectLink]',
        'start_command': 'str',
        'status': 'str',
        'status_last_updated': 'datetime',
        'status_reason': 'str',
        'tensorboard': 'ResponseService',
        'termination_protection': 'bool',
        'updated_dt': 'datetime',
        'version_control_project': 'ResponseVersionControlProject',
        'volume_mounts': 'ResponseVolumeMountInfos',
        'workspace': 'ResponseWorkspace',
        'workspace_id': 'int'
    }

    attribute_map = {
        'access_token_id': 'access_token_id',
        'cli_driven_project': 'cli_driven_project',
        'config_id': 'config_id',
        'created_by': 'created_by',
        'created_by_id': 'created_by_id',
        'created_dt': 'created_dt',
        'endpoints': 'endpoints',
        'env_vars': 'env_vars',
        'exit_code': 'exit_code',
        'experiment_access_token': 'experiment_access_token',
        'experiment_config': 'experiment_config',
        'experiment_config_kernel_image': 'experiment_config_kernel_image',
        'experiment_config_kernel_resource_spec': 'experiment_config_kernel_resource_spec',
        'experiment_created_by': 'experiment_created_by',
        'experiment_kernel_cluster': 'experiment_kernel_cluster',
        'experiment_kernel_cluster_node': 'experiment_kernel_cluster_node',
        'experiment_project': 'experiment_project',
        'experiment_workspace': 'experiment_workspace',
        'final_cost': 'final_cost',
        'histories': 'histories',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'kernel_cluster': 'kernel_cluster',
        'kernel_cluster_id': 'kernel_cluster_id',
        'kernel_cluster_node': 'kernel_cluster_node',
        'kernel_cluster_node_id': 'kernel_cluster_node_id',
        'kernel_cluster_select_policies': 'kernel_cluster_select_policies',
        'kernel_image': 'kernel_image',
        'kernel_image_id': 'kernel_image_id',
        'kernel_resource_spec': 'kernel_resource_spec',
        'kernel_resource_spec_id': 'kernel_resource_spec_id',
        'message': 'message',
        'metrics_summary': 'metrics_summary',
        'name': 'name',
        'number': 'number',
        'plot_volume_id': 'plot_volume_id',
        'project': 'project',
        'project_id': 'project_id',
        'reproduce_command': 'reproduce_command',
        'slug': 'slug',
        'source_code_link': 'source_code_link',
        'start_command': 'start_command',
        'status': 'status',
        'status_last_updated': 'status_last_updated',
        'status_reason': 'status_reason',
        'tensorboard': 'tensorboard',
        'termination_protection': 'termination_protection',
        'updated_dt': 'updated_dt',
        'version_control_project': 'version_control_project',
        'volume_mounts': 'volume_mounts',
        'workspace': 'workspace',
        'workspace_id': 'workspace_id'
    }

    def __init__(self, access_token_id=None, cli_driven_project=None, config_id=None, created_by=None, created_by_id=None, created_dt=None, endpoints=None, env_vars=None, exit_code=None, experiment_access_token=None, experiment_config=None, experiment_config_kernel_image=None, experiment_config_kernel_resource_spec=None, experiment_created_by=None, experiment_kernel_cluster=None, experiment_kernel_cluster_node=None, experiment_project=None, experiment_workspace=None, final_cost=None, histories=None, id=None, immutable_slug=None, kernel_cluster=None, kernel_cluster_id=None, kernel_cluster_node=None, kernel_cluster_node_id=None, kernel_cluster_select_policies=None, kernel_image=None, kernel_image_id=None, kernel_resource_spec=None, kernel_resource_spec_id=None, message=None, metrics_summary=None, name=None, number=None, plot_volume_id=None, project=None, project_id=None, reproduce_command=None, slug=None, source_code_link=None, start_command=None, status=None, status_last_updated=None, status_reason=None, tensorboard=None, termination_protection=None, updated_dt=None, version_control_project=None, volume_mounts=None, workspace=None, workspace_id=None, local_vars_configuration=None):  # noqa: E501
        """ResponseExperimentInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._access_token_id = None
        self._cli_driven_project = None
        self._config_id = None
        self._created_by = None
        self._created_by_id = None
        self._created_dt = None
        self._endpoints = None
        self._env_vars = None
        self._exit_code = None
        self._experiment_access_token = None
        self._experiment_config = None
        self._experiment_config_kernel_image = None
        self._experiment_config_kernel_resource_spec = None
        self._experiment_created_by = None
        self._experiment_kernel_cluster = None
        self._experiment_kernel_cluster_node = None
        self._experiment_project = None
        self._experiment_workspace = None
        self._final_cost = None
        self._histories = None
        self._id = None
        self._immutable_slug = None
        self._kernel_cluster = None
        self._kernel_cluster_id = None
        self._kernel_cluster_node = None
        self._kernel_cluster_node_id = None
        self._kernel_cluster_select_policies = None
        self._kernel_image = None
        self._kernel_image_id = None
        self._kernel_resource_spec = None
        self._kernel_resource_spec_id = None
        self._message = None
        self._metrics_summary = None
        self._name = None
        self._number = None
        self._plot_volume_id = None
        self._project = None
        self._project_id = None
        self._reproduce_command = None
        self._slug = None
        self._source_code_link = None
        self._start_command = None
        self._status = None
        self._status_last_updated = None
        self._status_reason = None
        self._tensorboard = None
        self._termination_protection = None
        self._updated_dt = None
        self._version_control_project = None
        self._volume_mounts = None
        self._workspace = None
        self._workspace_id = None
        self.discriminator = None

        self.access_token_id = access_token_id
        if cli_driven_project is not None:
            self.cli_driven_project = cli_driven_project
        self.config_id = config_id
        self.created_by = created_by
        self.created_by_id = created_by_id
        self.created_dt = created_dt
        self.endpoints = endpoints
        if env_vars is not None:
            self.env_vars = env_vars
        self.exit_code = exit_code
        self.experiment_access_token = experiment_access_token
        self.experiment_config = experiment_config
        self.experiment_config_kernel_image = experiment_config_kernel_image
        self.experiment_config_kernel_resource_spec = experiment_config_kernel_resource_spec
        self.experiment_created_by = experiment_created_by
        self.experiment_kernel_cluster = experiment_kernel_cluster
        self.experiment_kernel_cluster_node = experiment_kernel_cluster_node
        self.experiment_project = experiment_project
        self.experiment_workspace = experiment_workspace
        self.final_cost = final_cost
        self.histories = histories
        self.id = id
        self.immutable_slug = immutable_slug
        if kernel_cluster is not None:
            self.kernel_cluster = kernel_cluster
        self.kernel_cluster_id = kernel_cluster_id
        if kernel_cluster_node is not None:
            self.kernel_cluster_node = kernel_cluster_node
        self.kernel_cluster_node_id = kernel_cluster_node_id
        if kernel_cluster_select_policies is not None:
            self.kernel_cluster_select_policies = kernel_cluster_select_policies
        self.kernel_image = kernel_image
        self.kernel_image_id = kernel_image_id
        self.kernel_resource_spec = kernel_resource_spec
        self.kernel_resource_spec_id = kernel_resource_spec_id
        self.message = message
        if metrics_summary is not None:
            self.metrics_summary = metrics_summary
        self.name = name
        self.number = number
        self.plot_volume_id = plot_volume_id
        self.project = project
        self.project_id = project_id
        if reproduce_command is not None:
            self.reproduce_command = reproduce_command
        self.slug = slug
        self.source_code_link = source_code_link
        self.start_command = start_command
        self.status = status
        self.status_last_updated = status_last_updated
        self.status_reason = status_reason
        if tensorboard is not None:
            self.tensorboard = tensorboard
        self.termination_protection = termination_protection
        self.updated_dt = updated_dt
        if version_control_project is not None:
            self.version_control_project = version_control_project
        self.volume_mounts = volume_mounts
        self.workspace = workspace
        self.workspace_id = workspace_id

    @property
    def access_token_id(self):
        """Gets the access_token_id of this ResponseExperimentInfo.  # noqa: E501


        :return: The access_token_id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._access_token_id

    @access_token_id.setter
    def access_token_id(self, access_token_id):
        """Sets the access_token_id of this ResponseExperimentInfo.


        :param access_token_id: The access_token_id of this ResponseExperimentInfo.  # noqa: E501
        :type access_token_id: int
        """

        self._access_token_id = access_token_id

    @property
    def cli_driven_project(self):
        """Gets the cli_driven_project of this ResponseExperimentInfo.  # noqa: E501


        :return: The cli_driven_project of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseCLIDrivenProject
        """
        return self._cli_driven_project

    @cli_driven_project.setter
    def cli_driven_project(self, cli_driven_project):
        """Sets the cli_driven_project of this ResponseExperimentInfo.


        :param cli_driven_project: The cli_driven_project of this ResponseExperimentInfo.  # noqa: E501
        :type cli_driven_project: ResponseCLIDrivenProject
        """

        self._cli_driven_project = cli_driven_project

    @property
    def config_id(self):
        """Gets the config_id of this ResponseExperimentInfo.  # noqa: E501


        :return: The config_id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._config_id

    @config_id.setter
    def config_id(self, config_id):
        """Sets the config_id of this ResponseExperimentInfo.


        :param config_id: The config_id of this ResponseExperimentInfo.  # noqa: E501
        :type config_id: int
        """
        if self.local_vars_configuration.client_side_validation and config_id is None:  # noqa: E501
            raise ValueError("Invalid value for `config_id`, must not be `None`")  # noqa: E501

        self._config_id = config_id

    @property
    def created_by(self):
        """Gets the created_by of this ResponseExperimentInfo.  # noqa: E501


        :return: The created_by of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ResponseExperimentInfo.


        :param created_by: The created_by of this ResponseExperimentInfo.  # noqa: E501
        :type created_by: ResponseUser
        """
        if self.local_vars_configuration.client_side_validation and created_by is None:  # noqa: E501
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def created_by_id(self):
        """Gets the created_by_id of this ResponseExperimentInfo.  # noqa: E501


        :return: The created_by_id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """Sets the created_by_id of this ResponseExperimentInfo.


        :param created_by_id: The created_by_id of this ResponseExperimentInfo.  # noqa: E501
        :type created_by_id: int
        """
        if self.local_vars_configuration.client_side_validation and created_by_id is None:  # noqa: E501
            raise ValueError("Invalid value for `created_by_id`, must not be `None`")  # noqa: E501

        self._created_by_id = created_by_id

    @property
    def created_dt(self):
        """Gets the created_dt of this ResponseExperimentInfo.  # noqa: E501


        :return: The created_dt of this ResponseExperimentInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ResponseExperimentInfo.


        :param created_dt: The created_dt of this ResponseExperimentInfo.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def endpoints(self):
        """Gets the endpoints of this ResponseExperimentInfo.  # noqa: E501


        :return: The endpoints of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseServiceEndpoints
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """Sets the endpoints of this ResponseExperimentInfo.


        :param endpoints: The endpoints of this ResponseExperimentInfo.  # noqa: E501
        :type endpoints: ResponseServiceEndpoints
        """
        if self.local_vars_configuration.client_side_validation and endpoints is None:  # noqa: E501
            raise ValueError("Invalid value for `endpoints`, must not be `None`")  # noqa: E501

        self._endpoints = endpoints

    @property
    def env_vars(self):
        """Gets the env_vars of this ResponseExperimentInfo.  # noqa: E501


        :return: The env_vars of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ModelEnvVars
        """
        return self._env_vars

    @env_vars.setter
    def env_vars(self, env_vars):
        """Sets the env_vars of this ResponseExperimentInfo.


        :param env_vars: The env_vars of this ResponseExperimentInfo.  # noqa: E501
        :type env_vars: ModelEnvVars
        """

        self._env_vars = env_vars

    @property
    def exit_code(self):
        """Gets the exit_code of this ResponseExperimentInfo.  # noqa: E501


        :return: The exit_code of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._exit_code

    @exit_code.setter
    def exit_code(self, exit_code):
        """Sets the exit_code of this ResponseExperimentInfo.


        :param exit_code: The exit_code of this ResponseExperimentInfo.  # noqa: E501
        :type exit_code: int
        """

        self._exit_code = exit_code

    @property
    def experiment_access_token(self):
        """Gets the experiment_access_token of this ResponseExperimentInfo.  # noqa: E501


        :return: The experiment_access_token of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_access_token

    @experiment_access_token.setter
    def experiment_access_token(self, experiment_access_token):
        """Sets the experiment_access_token of this ResponseExperimentInfo.


        :param experiment_access_token: The experiment_access_token of this ResponseExperimentInfo.  # noqa: E501
        :type experiment_access_token: int
        """

        self._experiment_access_token = experiment_access_token

    @property
    def experiment_config(self):
        """Gets the experiment_config of this ResponseExperimentInfo.  # noqa: E501


        :return: The experiment_config of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_config

    @experiment_config.setter
    def experiment_config(self, experiment_config):
        """Sets the experiment_config of this ResponseExperimentInfo.


        :param experiment_config: The experiment_config of this ResponseExperimentInfo.  # noqa: E501
        :type experiment_config: int
        """
        if self.local_vars_configuration.client_side_validation and experiment_config is None:  # noqa: E501
            raise ValueError("Invalid value for `experiment_config`, must not be `None`")  # noqa: E501

        self._experiment_config = experiment_config

    @property
    def experiment_config_kernel_image(self):
        """Gets the experiment_config_kernel_image of this ResponseExperimentInfo.  # noqa: E501


        :return: The experiment_config_kernel_image of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_config_kernel_image

    @experiment_config_kernel_image.setter
    def experiment_config_kernel_image(self, experiment_config_kernel_image):
        """Sets the experiment_config_kernel_image of this ResponseExperimentInfo.


        :param experiment_config_kernel_image: The experiment_config_kernel_image of this ResponseExperimentInfo.  # noqa: E501
        :type experiment_config_kernel_image: int
        """
        if self.local_vars_configuration.client_side_validation and experiment_config_kernel_image is None:  # noqa: E501
            raise ValueError("Invalid value for `experiment_config_kernel_image`, must not be `None`")  # noqa: E501

        self._experiment_config_kernel_image = experiment_config_kernel_image

    @property
    def experiment_config_kernel_resource_spec(self):
        """Gets the experiment_config_kernel_resource_spec of this ResponseExperimentInfo.  # noqa: E501


        :return: The experiment_config_kernel_resource_spec of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_config_kernel_resource_spec

    @experiment_config_kernel_resource_spec.setter
    def experiment_config_kernel_resource_spec(self, experiment_config_kernel_resource_spec):
        """Sets the experiment_config_kernel_resource_spec of this ResponseExperimentInfo.


        :param experiment_config_kernel_resource_spec: The experiment_config_kernel_resource_spec of this ResponseExperimentInfo.  # noqa: E501
        :type experiment_config_kernel_resource_spec: int
        """

        self._experiment_config_kernel_resource_spec = experiment_config_kernel_resource_spec

    @property
    def experiment_created_by(self):
        """Gets the experiment_created_by of this ResponseExperimentInfo.  # noqa: E501


        :return: The experiment_created_by of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_created_by

    @experiment_created_by.setter
    def experiment_created_by(self, experiment_created_by):
        """Sets the experiment_created_by of this ResponseExperimentInfo.


        :param experiment_created_by: The experiment_created_by of this ResponseExperimentInfo.  # noqa: E501
        :type experiment_created_by: int
        """
        if self.local_vars_configuration.client_side_validation and experiment_created_by is None:  # noqa: E501
            raise ValueError("Invalid value for `experiment_created_by`, must not be `None`")  # noqa: E501

        self._experiment_created_by = experiment_created_by

    @property
    def experiment_kernel_cluster(self):
        """Gets the experiment_kernel_cluster of this ResponseExperimentInfo.  # noqa: E501


        :return: The experiment_kernel_cluster of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_kernel_cluster

    @experiment_kernel_cluster.setter
    def experiment_kernel_cluster(self, experiment_kernel_cluster):
        """Sets the experiment_kernel_cluster of this ResponseExperimentInfo.


        :param experiment_kernel_cluster: The experiment_kernel_cluster of this ResponseExperimentInfo.  # noqa: E501
        :type experiment_kernel_cluster: int
        """

        self._experiment_kernel_cluster = experiment_kernel_cluster

    @property
    def experiment_kernel_cluster_node(self):
        """Gets the experiment_kernel_cluster_node of this ResponseExperimentInfo.  # noqa: E501


        :return: The experiment_kernel_cluster_node of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_kernel_cluster_node

    @experiment_kernel_cluster_node.setter
    def experiment_kernel_cluster_node(self, experiment_kernel_cluster_node):
        """Sets the experiment_kernel_cluster_node of this ResponseExperimentInfo.


        :param experiment_kernel_cluster_node: The experiment_kernel_cluster_node of this ResponseExperimentInfo.  # noqa: E501
        :type experiment_kernel_cluster_node: int
        """

        self._experiment_kernel_cluster_node = experiment_kernel_cluster_node

    @property
    def experiment_project(self):
        """Gets the experiment_project of this ResponseExperimentInfo.  # noqa: E501


        :return: The experiment_project of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_project

    @experiment_project.setter
    def experiment_project(self, experiment_project):
        """Sets the experiment_project of this ResponseExperimentInfo.


        :param experiment_project: The experiment_project of this ResponseExperimentInfo.  # noqa: E501
        :type experiment_project: int
        """
        if self.local_vars_configuration.client_side_validation and experiment_project is None:  # noqa: E501
            raise ValueError("Invalid value for `experiment_project`, must not be `None`")  # noqa: E501

        self._experiment_project = experiment_project

    @property
    def experiment_workspace(self):
        """Gets the experiment_workspace of this ResponseExperimentInfo.  # noqa: E501


        :return: The experiment_workspace of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_workspace

    @experiment_workspace.setter
    def experiment_workspace(self, experiment_workspace):
        """Sets the experiment_workspace of this ResponseExperimentInfo.


        :param experiment_workspace: The experiment_workspace of this ResponseExperimentInfo.  # noqa: E501
        :type experiment_workspace: int
        """
        if self.local_vars_configuration.client_side_validation and experiment_workspace is None:  # noqa: E501
            raise ValueError("Invalid value for `experiment_workspace`, must not be `None`")  # noqa: E501

        self._experiment_workspace = experiment_workspace

    @property
    def final_cost(self):
        """Gets the final_cost of this ResponseExperimentInfo.  # noqa: E501


        :return: The final_cost of this ResponseExperimentInfo.  # noqa: E501
        :rtype: float
        """
        return self._final_cost

    @final_cost.setter
    def final_cost(self, final_cost):
        """Sets the final_cost of this ResponseExperimentInfo.


        :param final_cost: The final_cost of this ResponseExperimentInfo.  # noqa: E501
        :type final_cost: float
        """

        self._final_cost = final_cost

    @property
    def histories(self):
        """Gets the histories of this ResponseExperimentInfo.  # noqa: E501


        :return: The histories of this ResponseExperimentInfo.  # noqa: E501
        :rtype: list[ResponseExperimentHistoryInfo]
        """
        return self._histories

    @histories.setter
    def histories(self, histories):
        """Sets the histories of this ResponseExperimentInfo.


        :param histories: The histories of this ResponseExperimentInfo.  # noqa: E501
        :type histories: list[ResponseExperimentHistoryInfo]
        """
        if self.local_vars_configuration.client_side_validation and histories is None:  # noqa: E501
            raise ValueError("Invalid value for `histories`, must not be `None`")  # noqa: E501

        self._histories = histories

    @property
    def id(self):
        """Gets the id of this ResponseExperimentInfo.  # noqa: E501


        :return: The id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseExperimentInfo.


        :param id: The id of this ResponseExperimentInfo.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this ResponseExperimentInfo.  # noqa: E501


        :return: The immutable_slug of this ResponseExperimentInfo.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this ResponseExperimentInfo.


        :param immutable_slug: The immutable_slug of this ResponseExperimentInfo.  # noqa: E501
        :type immutable_slug: str
        """
        if self.local_vars_configuration.client_side_validation and immutable_slug is None:  # noqa: E501
            raise ValueError("Invalid value for `immutable_slug`, must not be `None`")  # noqa: E501

        self._immutable_slug = immutable_slug

    @property
    def kernel_cluster(self):
        """Gets the kernel_cluster of this ResponseExperimentInfo.  # noqa: E501


        :return: The kernel_cluster of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseKernelCluster
        """
        return self._kernel_cluster

    @kernel_cluster.setter
    def kernel_cluster(self, kernel_cluster):
        """Sets the kernel_cluster of this ResponseExperimentInfo.


        :param kernel_cluster: The kernel_cluster of this ResponseExperimentInfo.  # noqa: E501
        :type kernel_cluster: ResponseKernelCluster
        """

        self._kernel_cluster = kernel_cluster

    @property
    def kernel_cluster_id(self):
        """Gets the kernel_cluster_id of this ResponseExperimentInfo.  # noqa: E501


        :return: The kernel_cluster_id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._kernel_cluster_id

    @kernel_cluster_id.setter
    def kernel_cluster_id(self, kernel_cluster_id):
        """Sets the kernel_cluster_id of this ResponseExperimentInfo.


        :param kernel_cluster_id: The kernel_cluster_id of this ResponseExperimentInfo.  # noqa: E501
        :type kernel_cluster_id: int
        """

        self._kernel_cluster_id = kernel_cluster_id

    @property
    def kernel_cluster_node(self):
        """Gets the kernel_cluster_node of this ResponseExperimentInfo.  # noqa: E501


        :return: The kernel_cluster_node of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseKernelClusterNode
        """
        return self._kernel_cluster_node

    @kernel_cluster_node.setter
    def kernel_cluster_node(self, kernel_cluster_node):
        """Sets the kernel_cluster_node of this ResponseExperimentInfo.


        :param kernel_cluster_node: The kernel_cluster_node of this ResponseExperimentInfo.  # noqa: E501
        :type kernel_cluster_node: ResponseKernelClusterNode
        """

        self._kernel_cluster_node = kernel_cluster_node

    @property
    def kernel_cluster_node_id(self):
        """Gets the kernel_cluster_node_id of this ResponseExperimentInfo.  # noqa: E501


        :return: The kernel_cluster_node_id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._kernel_cluster_node_id

    @kernel_cluster_node_id.setter
    def kernel_cluster_node_id(self, kernel_cluster_node_id):
        """Sets the kernel_cluster_node_id of this ResponseExperimentInfo.


        :param kernel_cluster_node_id: The kernel_cluster_node_id of this ResponseExperimentInfo.  # noqa: E501
        :type kernel_cluster_node_id: int
        """

        self._kernel_cluster_node_id = kernel_cluster_node_id

    @property
    def kernel_cluster_select_policies(self):
        """Gets the kernel_cluster_select_policies of this ResponseExperimentInfo.  # noqa: E501


        :return: The kernel_cluster_select_policies of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ModelKernelClusterSelectPolicies
        """
        return self._kernel_cluster_select_policies

    @kernel_cluster_select_policies.setter
    def kernel_cluster_select_policies(self, kernel_cluster_select_policies):
        """Sets the kernel_cluster_select_policies of this ResponseExperimentInfo.


        :param kernel_cluster_select_policies: The kernel_cluster_select_policies of this ResponseExperimentInfo.  # noqa: E501
        :type kernel_cluster_select_policies: ModelKernelClusterSelectPolicies
        """

        self._kernel_cluster_select_policies = kernel_cluster_select_policies

    @property
    def kernel_image(self):
        """Gets the kernel_image of this ResponseExperimentInfo.  # noqa: E501


        :return: The kernel_image of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseKernelImage
        """
        return self._kernel_image

    @kernel_image.setter
    def kernel_image(self, kernel_image):
        """Sets the kernel_image of this ResponseExperimentInfo.


        :param kernel_image: The kernel_image of this ResponseExperimentInfo.  # noqa: E501
        :type kernel_image: ResponseKernelImage
        """
        if self.local_vars_configuration.client_side_validation and kernel_image is None:  # noqa: E501
            raise ValueError("Invalid value for `kernel_image`, must not be `None`")  # noqa: E501

        self._kernel_image = kernel_image

    @property
    def kernel_image_id(self):
        """Gets the kernel_image_id of this ResponseExperimentInfo.  # noqa: E501


        :return: The kernel_image_id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._kernel_image_id

    @kernel_image_id.setter
    def kernel_image_id(self, kernel_image_id):
        """Sets the kernel_image_id of this ResponseExperimentInfo.


        :param kernel_image_id: The kernel_image_id of this ResponseExperimentInfo.  # noqa: E501
        :type kernel_image_id: int
        """
        if self.local_vars_configuration.client_side_validation and kernel_image_id is None:  # noqa: E501
            raise ValueError("Invalid value for `kernel_image_id`, must not be `None`")  # noqa: E501

        self._kernel_image_id = kernel_image_id

    @property
    def kernel_resource_spec(self):
        """Gets the kernel_resource_spec of this ResponseExperimentInfo.  # noqa: E501


        :return: The kernel_resource_spec of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseKernelResourceSpec
        """
        return self._kernel_resource_spec

    @kernel_resource_spec.setter
    def kernel_resource_spec(self, kernel_resource_spec):
        """Sets the kernel_resource_spec of this ResponseExperimentInfo.


        :param kernel_resource_spec: The kernel_resource_spec of this ResponseExperimentInfo.  # noqa: E501
        :type kernel_resource_spec: ResponseKernelResourceSpec
        """
        if self.local_vars_configuration.client_side_validation and kernel_resource_spec is None:  # noqa: E501
            raise ValueError("Invalid value for `kernel_resource_spec`, must not be `None`")  # noqa: E501

        self._kernel_resource_spec = kernel_resource_spec

    @property
    def kernel_resource_spec_id(self):
        """Gets the kernel_resource_spec_id of this ResponseExperimentInfo.  # noqa: E501


        :return: The kernel_resource_spec_id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._kernel_resource_spec_id

    @kernel_resource_spec_id.setter
    def kernel_resource_spec_id(self, kernel_resource_spec_id):
        """Sets the kernel_resource_spec_id of this ResponseExperimentInfo.


        :param kernel_resource_spec_id: The kernel_resource_spec_id of this ResponseExperimentInfo.  # noqa: E501
        :type kernel_resource_spec_id: int
        """

        self._kernel_resource_spec_id = kernel_resource_spec_id

    @property
    def message(self):
        """Gets the message of this ResponseExperimentInfo.  # noqa: E501


        :return: The message of this ResponseExperimentInfo.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ResponseExperimentInfo.


        :param message: The message of this ResponseExperimentInfo.  # noqa: E501
        :type message: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def metrics_summary(self):
        """Gets the metrics_summary of this ResponseExperimentInfo.  # noqa: E501


        :return: The metrics_summary of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ModelExperimentMetricsSummary
        """
        return self._metrics_summary

    @metrics_summary.setter
    def metrics_summary(self, metrics_summary):
        """Sets the metrics_summary of this ResponseExperimentInfo.


        :param metrics_summary: The metrics_summary of this ResponseExperimentInfo.  # noqa: E501
        :type metrics_summary: ModelExperimentMetricsSummary
        """

        self._metrics_summary = metrics_summary

    @property
    def name(self):
        """Gets the name of this ResponseExperimentInfo.  # noqa: E501


        :return: The name of this ResponseExperimentInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResponseExperimentInfo.


        :param name: The name of this ResponseExperimentInfo.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def number(self):
        """Gets the number of this ResponseExperimentInfo.  # noqa: E501


        :return: The number of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this ResponseExperimentInfo.


        :param number: The number of this ResponseExperimentInfo.  # noqa: E501
        :type number: int
        """
        if self.local_vars_configuration.client_side_validation and number is None:  # noqa: E501
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def plot_volume_id(self):
        """Gets the plot_volume_id of this ResponseExperimentInfo.  # noqa: E501


        :return: The plot_volume_id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._plot_volume_id

    @plot_volume_id.setter
    def plot_volume_id(self, plot_volume_id):
        """Sets the plot_volume_id of this ResponseExperimentInfo.


        :param plot_volume_id: The plot_volume_id of this ResponseExperimentInfo.  # noqa: E501
        :type plot_volume_id: int
        """
        if self.local_vars_configuration.client_side_validation and plot_volume_id is None:  # noqa: E501
            raise ValueError("Invalid value for `plot_volume_id`, must not be `None`")  # noqa: E501

        self._plot_volume_id = plot_volume_id

    @property
    def project(self):
        """Gets the project of this ResponseExperimentInfo.  # noqa: E501


        :return: The project of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseProject
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ResponseExperimentInfo.


        :param project: The project of this ResponseExperimentInfo.  # noqa: E501
        :type project: ResponseProject
        """
        if self.local_vars_configuration.client_side_validation and project is None:  # noqa: E501
            raise ValueError("Invalid value for `project`, must not be `None`")  # noqa: E501

        self._project = project

    @property
    def project_id(self):
        """Gets the project_id of this ResponseExperimentInfo.  # noqa: E501


        :return: The project_id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ResponseExperimentInfo.


        :param project_id: The project_id of this ResponseExperimentInfo.  # noqa: E501
        :type project_id: int
        """
        if self.local_vars_configuration.client_side_validation and project_id is None:  # noqa: E501
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def reproduce_command(self):
        """Gets the reproduce_command of this ResponseExperimentInfo.  # noqa: E501


        :return: The reproduce_command of this ResponseExperimentInfo.  # noqa: E501
        :rtype: str
        """
        return self._reproduce_command

    @reproduce_command.setter
    def reproduce_command(self, reproduce_command):
        """Sets the reproduce_command of this ResponseExperimentInfo.


        :param reproduce_command: The reproduce_command of this ResponseExperimentInfo.  # noqa: E501
        :type reproduce_command: str
        """

        self._reproduce_command = reproduce_command

    @property
    def slug(self):
        """Gets the slug of this ResponseExperimentInfo.  # noqa: E501


        :return: The slug of this ResponseExperimentInfo.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this ResponseExperimentInfo.


        :param slug: The slug of this ResponseExperimentInfo.  # noqa: E501
        :type slug: str
        """
        if self.local_vars_configuration.client_side_validation and slug is None:  # noqa: E501
            raise ValueError("Invalid value for `slug`, must not be `None`")  # noqa: E501

        self._slug = slug

    @property
    def source_code_link(self):
        """Gets the source_code_link of this ResponseExperimentInfo.  # noqa: E501


        :return: The source_code_link of this ResponseExperimentInfo.  # noqa: E501
        :rtype: list[ResponseProjectLink]
        """
        return self._source_code_link

    @source_code_link.setter
    def source_code_link(self, source_code_link):
        """Sets the source_code_link of this ResponseExperimentInfo.


        :param source_code_link: The source_code_link of this ResponseExperimentInfo.  # noqa: E501
        :type source_code_link: list[ResponseProjectLink]
        """
        if self.local_vars_configuration.client_side_validation and source_code_link is None:  # noqa: E501
            raise ValueError("Invalid value for `source_code_link`, must not be `None`")  # noqa: E501

        self._source_code_link = source_code_link

    @property
    def start_command(self):
        """Gets the start_command of this ResponseExperimentInfo.  # noqa: E501


        :return: The start_command of this ResponseExperimentInfo.  # noqa: E501
        :rtype: str
        """
        return self._start_command

    @start_command.setter
    def start_command(self, start_command):
        """Sets the start_command of this ResponseExperimentInfo.


        :param start_command: The start_command of this ResponseExperimentInfo.  # noqa: E501
        :type start_command: str
        """
        if self.local_vars_configuration.client_side_validation and start_command is None:  # noqa: E501
            raise ValueError("Invalid value for `start_command`, must not be `None`")  # noqa: E501

        self._start_command = start_command

    @property
    def status(self):
        """Gets the status of this ResponseExperimentInfo.  # noqa: E501


        :return: The status of this ResponseExperimentInfo.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseExperimentInfo.


        :param status: The status of this ResponseExperimentInfo.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def status_last_updated(self):
        """Gets the status_last_updated of this ResponseExperimentInfo.  # noqa: E501


        :return: The status_last_updated of this ResponseExperimentInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._status_last_updated

    @status_last_updated.setter
    def status_last_updated(self, status_last_updated):
        """Sets the status_last_updated of this ResponseExperimentInfo.


        :param status_last_updated: The status_last_updated of this ResponseExperimentInfo.  # noqa: E501
        :type status_last_updated: datetime
        """
        if self.local_vars_configuration.client_side_validation and status_last_updated is None:  # noqa: E501
            raise ValueError("Invalid value for `status_last_updated`, must not be `None`")  # noqa: E501

        self._status_last_updated = status_last_updated

    @property
    def status_reason(self):
        """Gets the status_reason of this ResponseExperimentInfo.  # noqa: E501


        :return: The status_reason of this ResponseExperimentInfo.  # noqa: E501
        :rtype: str
        """
        return self._status_reason

    @status_reason.setter
    def status_reason(self, status_reason):
        """Sets the status_reason of this ResponseExperimentInfo.


        :param status_reason: The status_reason of this ResponseExperimentInfo.  # noqa: E501
        :type status_reason: str
        """
        if self.local_vars_configuration.client_side_validation and status_reason is None:  # noqa: E501
            raise ValueError("Invalid value for `status_reason`, must not be `None`")  # noqa: E501

        self._status_reason = status_reason

    @property
    def tensorboard(self):
        """Gets the tensorboard of this ResponseExperimentInfo.  # noqa: E501


        :return: The tensorboard of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseService
        """
        return self._tensorboard

    @tensorboard.setter
    def tensorboard(self, tensorboard):
        """Sets the tensorboard of this ResponseExperimentInfo.


        :param tensorboard: The tensorboard of this ResponseExperimentInfo.  # noqa: E501
        :type tensorboard: ResponseService
        """

        self._tensorboard = tensorboard

    @property
    def termination_protection(self):
        """Gets the termination_protection of this ResponseExperimentInfo.  # noqa: E501


        :return: The termination_protection of this ResponseExperimentInfo.  # noqa: E501
        :rtype: bool
        """
        return self._termination_protection

    @termination_protection.setter
    def termination_protection(self, termination_protection):
        """Sets the termination_protection of this ResponseExperimentInfo.


        :param termination_protection: The termination_protection of this ResponseExperimentInfo.  # noqa: E501
        :type termination_protection: bool
        """
        if self.local_vars_configuration.client_side_validation and termination_protection is None:  # noqa: E501
            raise ValueError("Invalid value for `termination_protection`, must not be `None`")  # noqa: E501

        self._termination_protection = termination_protection

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ResponseExperimentInfo.  # noqa: E501


        :return: The updated_dt of this ResponseExperimentInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ResponseExperimentInfo.


        :param updated_dt: The updated_dt of this ResponseExperimentInfo.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def version_control_project(self):
        """Gets the version_control_project of this ResponseExperimentInfo.  # noqa: E501


        :return: The version_control_project of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseVersionControlProject
        """
        return self._version_control_project

    @version_control_project.setter
    def version_control_project(self, version_control_project):
        """Sets the version_control_project of this ResponseExperimentInfo.


        :param version_control_project: The version_control_project of this ResponseExperimentInfo.  # noqa: E501
        :type version_control_project: ResponseVersionControlProject
        """

        self._version_control_project = version_control_project

    @property
    def volume_mounts(self):
        """Gets the volume_mounts of this ResponseExperimentInfo.  # noqa: E501


        :return: The volume_mounts of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseVolumeMountInfos
        """
        return self._volume_mounts

    @volume_mounts.setter
    def volume_mounts(self, volume_mounts):
        """Sets the volume_mounts of this ResponseExperimentInfo.


        :param volume_mounts: The volume_mounts of this ResponseExperimentInfo.  # noqa: E501
        :type volume_mounts: ResponseVolumeMountInfos
        """
        if self.local_vars_configuration.client_side_validation and volume_mounts is None:  # noqa: E501
            raise ValueError("Invalid value for `volume_mounts`, must not be `None`")  # noqa: E501

        self._volume_mounts = volume_mounts

    @property
    def workspace(self):
        """Gets the workspace of this ResponseExperimentInfo.  # noqa: E501


        :return: The workspace of this ResponseExperimentInfo.  # noqa: E501
        :rtype: ResponseWorkspace
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this ResponseExperimentInfo.


        :param workspace: The workspace of this ResponseExperimentInfo.  # noqa: E501
        :type workspace: ResponseWorkspace
        """
        if self.local_vars_configuration.client_side_validation and workspace is None:  # noqa: E501
            raise ValueError("Invalid value for `workspace`, must not be `None`")  # noqa: E501

        self._workspace = workspace

    @property
    def workspace_id(self):
        """Gets the workspace_id of this ResponseExperimentInfo.  # noqa: E501


        :return: The workspace_id of this ResponseExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this ResponseExperimentInfo.


        :param workspace_id: The workspace_id of this ResponseExperimentInfo.  # noqa: E501
        :type workspace_id: int
        """
        if self.local_vars_configuration.client_side_validation and workspace_id is None:  # noqa: E501
            raise ValueError("Invalid value for `workspace_id`, must not be `None`")  # noqa: E501

        self._workspace_id = workspace_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseExperimentInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseExperimentInfo):
            return True

        return self.to_dict() != other.to_dict()
